@@ -1,6 +1,7 @@
 ###########################################
 package Net::Google::Drive::Simple;
 ###########################################
+
 use strict;
 use warnings;
 
@@ -12,25 +13,26 @@ use Sysadm::Install qw( slurp );
 use File::Basename;
 use YAML qw( LoadFile DumpFile );
 use JSON qw( from_json to_json );
-use Test::MockObject;
 use Log::Log4perl qw(:easy);
 use Data::Dumper;
 use File::MMagic;
 use OAuth::Cmdline::GoogleDrive;
 
-our $VERSION = "0.14";
+use Net::Google::Drive::Simple::Item;
+
+our $VERSION = '0.15';
 
 ###########################################
 sub new {
 ###########################################
-    my($class, %options) = @_;
+    my ( $class, %options ) = @_;
 
     my $self = {
-        init_done       => undef,
-        api_file_url    => "https://www.googleapis.com/drive/v2/files",
-        api_upload_url  => "https://www.googleapis.com/upload/drive/v2/files",
-        oauth           => OAuth::Cmdline::GoogleDrive->new( ),
-        error           => undef,
+        init_done      => undef,
+        api_file_url   => "https://www.googleapis.com/drive/v2/files",
+        api_upload_url => "https://www.googleapis.com/upload/drive/v2/files",
+        oauth          => OAuth::Cmdline::GoogleDrive->new(),
+        error          => undef,
         %options,
     };
 
@@ -40,30 +42,30 @@ sub new {
 ###########################################
 sub error {
 ###########################################
-    my( $self, $set ) = @_;
+    my ( $self, $set ) = @_;
 
-    if( defined $set ) {
-        $self->{ error } = $set;
+    if ( defined $set ) {
+        $self->{error} = $set;
     }
 
-    return $self->{ error };
+    return $self->{error};
 }
 
 ###########################################
 sub init {
 ###########################################
-    my( $self, $path ) = @_;
+    my ( $self, $path ) = @_;
 
-    if( $self->{ init_done } ) {
+    if ( $self->{init_done} ) {
         return 1;
     }
 
     DEBUG "Testing API";
-    if( !$self->api_test() ) {
+    if ( !$self->api_test() ) {
         LOGDIE "api_test failed";
     }
 
-    $self->{ init_done } = 1;
+    $self->{init_done} = 1;
 
     return 1;
 }
@@ -71,7 +73,7 @@ sub init {
 ###########################################
 sub api_test {
 ###########################################
-    my( $self ) = @_;
+    my ($self) = @_;
 
     my $url = $self->file_url( { maxResults => 1 } );
 
@@ -80,12 +82,12 @@ sub api_test {
     my $req = HTTP::Request->new(
         GET => $url->as_string,
     );
-    $req->header( $self->{ oauth }->authorization_headers() );
+    $req->header( $self->{oauth}->authorization_headers() );
     DEBUG "Fetching $url";
 
-    my $resp = $ua->request( $req );
+    my $resp = $ua->request($req);
 
-    if( $resp->is_success() ) {
+    if ( $resp->is_success() ) {
         DEBUG "API tested OK";
         return 1;
     }
@@ -99,7 +101,7 @@ sub api_test {
 ###########################################
 sub file_url {
 ###########################################
-    my( $self, $opts ) = @_;
+    my ( $self, $opts ) = @_;
 
     $opts = {} if !defined $opts;
 
@@ -112,8 +114,8 @@ sub file_url {
         %$opts,
     };
 
-    my $url = URI->new( $self->{ api_file_url } );
-    $url->query_form( $opts );
+    my $url = URI->new( $self->{api_file_url} );
+    $url->query_form($opts);
 
     return $url;
 }
@@ -121,9 +123,9 @@ sub file_url {
 ###########################################
 sub files {
 ###########################################
-    my( $self, $opts, $search_opts ) = @_;
+    my ( $self, $opts, $search_opts ) = @_;
 
-    if( !defined $search_opts ) {
+    if ( !defined $search_opts ) {
         $search_opts = {};
     }
     $search_opts = {
@@ -131,7 +133,7 @@ sub files {
         %$search_opts,
     };
 
-    if( !defined $opts ) {
+    if ( !defined $opts ) {
         $opts = {};
     }
 
@@ -139,33 +141,34 @@ sub files {
 
     my @docs = ();
 
-    while( 1 ) {
-        my $url = $self->file_url( $opts );
-        my $data = $self->http_json( $url );
+    while (1) {
+        my $url  = $self->file_url($opts);
+        my $data = $self->http_json($url);
 
-        if( !defined $data ) {
-            return undef;
-        }
+        return unless defined $data;
 
-        my $next_item = $self->item_iterator( $data );
+        my $next_item = $self->item_iterator($data);
 
-        while( my $item = $next_item->() ) {
-          if( $item->{ kind } eq "drive#file" ) {
-            my $file = $item->{ originalFilename };
-            if( !defined $file ) {
-                DEBUG "Skipping $item->{ title } (no originalFilename)";
-                next;
+        while ( my $item = $next_item->() ) {
+
+            if ( $item->{kind} eq "drive#file" ) {
+                my $file = $item->{originalFilename};
+                if ( !defined $file ) {
+                    DEBUG "Skipping $item->{ title } (no originalFilename)";
+                    next;
+                }
+
+                push @docs, $self->data_factory($item);
+            }
+            else {
+                DEBUG "Skipping $item->{ title } ($item->{ kind })";
             }
-
-            push @docs, $self->data_factory( $item );
-          } else {
-            DEBUG "Skipping $item->{ title } ($item->{ kind })";
-          }
         }
 
-        if( $search_opts->{ page } and $data->{ nextPageToken } ) {
-            $opts->{ pageToken } = $data->{ nextPageToken };
-        } else {
+        if ( $search_opts->{page} and $data->{nextPageToken} ) {
+            $opts->{pageToken} = $data->{nextPageToken};
+        }
+        else {
             last;
         }
     }
@@ -176,7 +179,7 @@ sub files {
 ###########################################
 sub folder_create {
 ###########################################
-    my( $self, $title, $parent ) = @_;
+    my ( $self, $title, $parent ) = @_;
 
     return $self->file_create( $title, "application/vnd.google-apps.folder", $parent );
 }
@@ -184,73 +187,74 @@ sub folder_create {
 ###########################################
 sub file_create {
 ###########################################
-    my( $self, $title, $mime_type, $parent ) = @_;
+    my ( $self, $title, $mime_type, $parent ) = @_;
 
-    my $url = URI->new( $self->{ api_file_url } );
+    my $url = URI->new( $self->{api_file_url} );
 
-    my $data = $self->http_json( $url, {
-        title    => $title,
-        parents  => [ { id => $parent } ],
-        mimeType => $mime_type,
-    } );
+    my $data = $self->http_json(
+        $url,
+        {
+            title    => $title,
+            parents  => [ { id => $parent } ],
+            mimeType => $mime_type,
+        }
+    );
 
-    if( ! defined $data ) {
-        return undef;
-    }
+    return unless defined $data;
 
-    return $data->{ id };
+    return $data->{id};
 }
 
 ###########################################
 sub file_upload {
 ###########################################
-    my( $self, $file, $parent_id, $file_id ) = @_;
+    my ( $self, $file, $parent_id, $file_id ) = @_;
 
-      # Since a file upload can take a long time, refresh the token
-      # just in case.
-    $self->{ oauth }->token_expire();
+    # Since a file upload can take a long time, refresh the token
+    # just in case.
+    $self->{oauth}->token_expire();
 
     my $title = basename $file;
 
-      # First, insert the file placeholder, according to
-      # http://stackoverflow.com/questions/10317638
+    # First, insert the file placeholder, according to
+    # http://stackoverflow.com/questions/10317638
     my $file_data = slurp $file;
-    my $mime_type = $self->file_mime_type( $file );
+    my $mime_type = $self->file_mime_type($file);
 
     my $url;
 
-    if( ! defined $file_id ) {
-        $url = URI->new( $self->{ api_file_url } );
+    if ( !defined $file_id ) {
+        $url = URI->new( $self->{api_file_url} );
 
-        my $data = $self->http_json( $url,
-            { mimeType => $mime_type,
-              parents  => [ { id => $parent_id } ],
-              title    => $title,
+        my $data = $self->http_json(
+            $url,
+            {
+                mimeType => $mime_type,
+                parents  => [ { id => $parent_id } ],
+                title    => $title,
             }
         );
 
-        if( ! defined $data ) {
-            return undef;
-        }
+        return unless defined $data;
 
-        $file_id = $data->{ id };
+        $file_id = $data->{id};
     }
 
-    $url = URI->new( $self->{ api_upload_url } . "/$file_id" );
+    $url = URI->new( $self->{api_upload_url} . "/$file_id" );
     $url->query_form( uploadType => "media" );
 
     my $req = &HTTP::Request::Common::PUT(
         $url->as_string,
-        $self->{ oauth }->authorization_headers(),
+        $self->{oauth}->authorization_headers(),
         "Content-Type" => $mime_type,
         Content        => $file_data,
     );
 
-    my $resp = $self->http_loop( $req );
+    my $resp = $self->http_loop($req);
 
-    if( $resp->is_error() ) {
+    if ( $resp->is_error() ) {
         $self->error( $self->message() );
-        return undef;
+        return;
     }
 
     DEBUG $resp->as_string;
@@ -261,24 +265,24 @@ sub file_upload {
 ###########################################
 sub file_mvdir {
 ###########################################
-    my( $self, $path, $target_folder ) = @_;
+    my ( $self, $path, $target_folder ) = @_;
 
     my $url;
 
-    if( !defined $path or !defined $target_folder ) {
+    if ( !defined $path or !defined $target_folder ) {
         LOGDIE "Missing parameter";
     }
 
     # Determine the file's parent in the path
-    my( $file_id, $folder_id ) = $self->path_resolve( $path );
+    my ( $file_id, $folder_id ) = $self->path_resolve($path);
 
-    if( !defined $file_id ) {
+    if ( !defined $file_id ) {
         LOGDIE "Cannot find source file: $path";
     }
 
-    my( $target_folder_id ) = $self->path_resolve( $target_folder );
+    my ($target_folder_id) = $self->path_resolve($target_folder);
 
-    if( !defined $target_folder_id ) {
+    if ( !defined $target_folder_id ) {
         LOGDIE "Cannot find destination path: $target_folder";
     }
 
@@ -286,55 +290,53 @@ sub file_mvdir {
     print "folder_id=$folder_id\n";
     print "target_folder_id=$target_folder_id\n";
 
-      # Delete it from the current parent
-    $url = URI->new( $self->{ api_file_url } .
-        "/$folder_id/children/$file_id" );
-    if( !$self->http_delete( $url ) ) {
+    # Delete it from the current parent
+    $url = URI->new( $self->{api_file_url} . "/$folder_id/children/$file_id" );
+    if ( !$self->http_delete($url) ) {
         LOGDIE "Failed to remove $path from parent folder.";
     }
 
-      # Add a new parent
-    $url = URI->new( $self->{ api_file_url } .
-        "/$target_folder_id/children" );
-    if( !$self->http_json( $url, { id => $file_id } ) ) {
+    # Add a new parent
+    $url = URI->new( $self->{api_file_url} . "/$target_folder_id/children" );
+    if ( !$self->http_json( $url, { id => $file_id } ) ) {
         LOGDIE "Failed to insert $path into $target_folder.";
     }
-    
+
     return 1;
 }
 
 ###########################################
 sub path_resolve {
 ###########################################
-    my( $self, $path, $search_opts ) = @_;
+    my ( $self, $path, $search_opts ) = @_;
 
     $search_opts = {} if !defined $search_opts;
 
-    my @parts = split '/', $path;
-    my @ids   = ();
+    my @parts  = split '/', $path;
+    my @ids    = ();
     my $parent = $parts[0] = "root";
     DEBUG "Parent: $parent";
 
     my $folder_id = shift @parts;
     push @ids, $folder_id;
 
-    PART: for my $part ( @parts ) {
+  PART: for my $part (@parts) {
 
         DEBUG "Looking up part $part (folder_id=$folder_id)";
 
-        my $children = $self->children_by_folder_id( $folder_id,
-          { maxResults    => 100, # path resolution maxResults is different
-          },
-          { %$search_opts, title => $part },
+        my $children = $self->children_by_folder_id(
+            $folder_id,
+            {
+                maxResults => 100,    # path resolution maxResults is different
+            },
+            { %$search_opts, title => $part },
         );
 
-        if( ! defined $children ) {
-            return undef;
-        }
+        return unless defined $children;
 
-        for my $child ( @$children ) {
+        for my $child (@$children) {
             DEBUG "Found child ", $child->title();
-            if( $child->title() eq $part ) {
+            if ( $child->title() eq $part ) {
                 $folder_id = $child->id();
                 unshift @ids, $folder_id;
                 $parent = $folder_id;
@@ -344,54 +346,55 @@ sub path_resolve {
         }
 
         my $msg = "Child $part not found";
-        $self->error( $msg );
+        $self->error($msg);
         ERROR $msg;
-        return undef;
+        return;
     }
 
-    if( @ids == 1 ) {
-          # parent of root is root
-        return( @ids, @ids );
+    if ( @ids == 1 ) {
+
+        # parent of root is root
+        return ( @ids, @ids );
     }
 
-    return( @ids );
+    return (@ids);
 }
 
 ###########################################
 sub file_delete {
 ###########################################
-    my( $self, $file_id ) = @_;
+    my ( $self, $file_id ) = @_;
 
     my $url;
 
-    LOGDIE 'Deletion requires file_id' if( ! defined $file_id );
+    LOGDIE 'Deletion requires file_id' if ( !defined $file_id );
 
-    $url = URI->new( $self->{ api_file_url } . "/$file_id" );
+    $url = URI->new( $self->{api_file_url} . "/$file_id" );
 
-    if( $self->http_delete( $url ) ) {
+    if ( $self->http_delete($url) ) {
         return $file_id;
     }
 
-    return undef;
+    return;
 }
 
 ###########################################
 sub http_delete {
 ###########################################
-    my( $self, $url ) = @_;
+    my ( $self, $url ) = @_;
 
     my $req = &HTTP::Request::Common::DELETE(
         $url,
-        $self->{ oauth }->authorization_headers(),
+        $self->{oauth}->authorization_headers(),
     );
 
-    my $resp = $self->http_loop( $req );
+    my $resp = $self->http_loop($req);
 
     DEBUG $resp->as_string;
 
-    if( $resp->is_error ) {
+    if ( $resp->is_error ) {
         $self->error( $resp->message() );
-        return undef;
+        return;
     }
 
     return 1;
@@ -400,52 +403,45 @@ sub http_delete {
 ###########################################
 sub children_by_folder_id {
 ###########################################
-    my( $self, $folder_id, $opts, $search_opts ) = @_;
+    my ( $self, $folder_id, $opts, $search_opts ) = @_;
 
     $self->init();
 
-    if( !defined $search_opts ) {
-        $search_opts = {};
-    }
+    $search_opts = {} unless defined $search_opts;
+    $search_opts->{page} = 1 unless exists $search_opts->{page};
 
-    $search_opts = {
-        page => 1,
-        %$search_opts,
-    };
-
-    if( !defined $opts ) {
+    if ( !defined $opts ) {
         $opts = {
             maxResults => 100,
         };
     }
 
-    my $url = URI->new( $self->{ api_file_url } );
-    $opts->{ q } = "'$folder_id' in parents";
+    my $url = URI->new( $self->{api_file_url} );
+    $opts->{'q'} = "'$folder_id' in parents";
 
-    if( $search_opts->{ title } ) {
-        $opts->{ q } .= " AND title = '$search_opts->{ title }'";
+    if ( $search_opts->{title} ) {
+        $opts->{'q'} .= " AND title = '$search_opts->{ title }'";    # ' fix for poor editors
     }
 
     my @children = ();
 
-    while( 1 ) {
-        $url->query_form( $opts );
+    while (1) {
+        $url->query_form($opts);
 
-        my $data = $self->http_json( $url );
+        my $data = $self->http_json($url);
 
-        if( ! defined $data ) {
-            return undef;
+        return unless defined $data;
+
+        my $next_item = $self->item_iterator($data);
+
+        while ( my $item = $next_item->() ) {
+            push @children, $self->data_factory($item);
         }
 
-        my $next_item = $self->item_iterator( $data );
-
-        while( my $item = $next_item->() ) {
-            push @children, $self->data_factory( $item );
+        if ( $search_opts->{page} and $data->{nextPageToken} ) {
+            $opts->{pageToken} = $data->{nextPageToken};
         }
-
-        if( $search_opts->{ page } and $data->{ nextPageToken } ) {
-            $opts->{ pageToken } = $data->{ nextPageToken };
-        } else {
+        else {
             last;
         }
     }
@@ -456,77 +452,64 @@ sub children_by_folder_id {
 ###########################################
 sub children {
 ###########################################
-    my( $self, $path, $opts, $search_opts ) = @_;
+    my ( $self, $path, $opts, $search_opts ) = @_;
 
     DEBUG "Determine children of $path";
+    LOGDIE "No $path given" unless defined $path;
 
-    if( !defined $path ) {
-        LOGDIE "No $path given";
-    }
+    $search_opts = {} unless defined $search_opts;
 
-    if( !defined $search_opts ) {
-        $search_opts = {};
-    }
+    my ( $folder_id, $parent ) = $self->path_resolve( $path, $search_opts );
 
-    my( $folder_id, $parent ) = $self->path_resolve( $path, $search_opts );
-
-    if( !defined $folder_id ) {
-        return undef;
-    }
+    return unless defined $folder_id;
 
     DEBUG "Getting content of folder $folder_id";
+    my $children = $self->children_by_folder_id(
+        $folder_id, $opts,
+        $search_opts
+    );
 
-    my $children = $self->children_by_folder_id( $folder_id, $opts,
-        $search_opts );
+    return unless defined $children;
 
-    if( ! defined $children ) {
-        return undef;
-    }
-
-    if( wantarray ) {
-        return( $children, $folder_id );
-    } else {
-        return $children;
-    }
+    return wantarray ? ( $children, $folder_id ) : $children;
 }
 
 ###########################################
 sub search {
 ###########################################
-    my( $self, $opts, $search_opts, $query ) = @_;
-    $search_opts||= { page => 1 };
+    my ( $self, $opts, $search_opts, $query ) = @_;
+    $search_opts ||= { page => 1 };
 
     $self->init();
 
-    if( !defined $opts ) {
+    if ( !defined $opts ) {
         $opts = {
             maxResults => 100,
         };
     }
 
-    my $url = URI->new( $self->{ api_file_url } );
+    my $url = URI->new( $self->{api_file_url} );
 
-    $opts->{ q }= $query;
+    $opts->{'q'} = $query;
 
     my @children = ();
 
-    while( 1 ) {
-        $url->query_form( $opts );
+    while (1) {
+        $url->query_form($opts);
 
-        my $data = $self->http_json( $url );
-        if( ! defined $data ) {
-            return undef;
+        my $data = $self->http_json($url);
+        return unless defined $data;
+
+        my $next_item = $self->item_iterator($data);
+
+        while ( my $item = $next_item->() ) {
+            push @children, $self->data_factory($item);
         }
 
-        my $next_item = $self->item_iterator( $data );
-
-        while( my $item = $next_item->() ) {
-            push @children, $self->data_factory( $item );
+        if ( $search_opts->{page} and $data->{nextPageToken} ) {
+            $opts->{pageToken} = $data->{nextPageToken};
         }
-
-        if( $search_opts->{ page } and $data->{ nextPageToken } ) {
-            $opts->{ pageToken } = $data->{ nextPageToken };
-        } else {
+        else {
             last;
         }
     }
@@ -537,54 +520,46 @@ sub search {
 ###########################################
 sub data_factory {
 ###########################################
-    my( $self, $data ) = @_;
+    my ( $self, $data ) = @_;
 
-    my $mock = Test::MockObject->new();
-
-    for my $key ( keys %$data ) {
-        # DEBUG "Adding method $key";
-        $mock->mock( $key , sub { $data->{ $key } } );
-    }
-
-    return $mock;
+    return Net::Google::Drive::Simple::Item->new($data);
 }
 
 ###########################################
 sub download {
 ###########################################
-    my( $self, $url, $local_file ) = @_;
+    my ( $self, $url, $local_file ) = @_;
 
-    if( ref $url ) {
+    if ( ref $url ) {
         $url = $url->downloadUrl();
     }
 
     my $req = HTTP::Request->new(
         GET => $url,
     );
-    $req->header( $self->{ oauth }->authorization_headers() );
+    $req->header( $self->{oauth}->authorization_headers() );
 
     my $ua = LWP::UserAgent->new();
     my $resp = $ua->request( $req, $local_file );
 
-    if( $resp->is_error() ) {
+    if ( $resp->is_error() ) {
         my $msg = "Can't download $url (" . $resp->message() . ")";
         ERROR $msg;
-        $self->error( $msg );
-        return undef;
+        $self->error($msg);
+        return;
     }
 
-    if( $local_file ) {
+    if ($local_file) {
         return 1;
     }
 
     return $resp->content();
 }
 
-
 ###########################################
 sub http_loop {
 ###########################################
-    my( $self, $req, $noinit ) = @_;
+    my ( $self, $req, $noinit ) = @_;
 
     my $ua = LWP::UserAgent->new();
     my $resp;
@@ -593,23 +568,24 @@ sub http_loop {
     my $SLEEP_INTERVAL = 10;
 
     {
-          # refresh token if necessary
-        if( ! $noinit ) {
+        # refresh token if necessary
+        if ( !$noinit ) {
             $self->init();
         }
 
         DEBUG "Fetching ", $req->url->as_string();
 
-        $resp = $ua->request( $req );
+        $resp = $ua->request($req);
 
-        if( ! $resp->is_success() ) {
+        if ( !$resp->is_success() ) {
             $self->error( $resp->message() );
             warn "Failed with ", $resp->code(), ": ", $resp->message();
-            if( --$RETRIES >= 0 ) {
+            if ( --$RETRIES >= 0 ) {
                 ERROR "Retrying in $SLEEP_INTERVAL seconds";
                 sleep $SLEEP_INTERVAL;
                 redo;
-            } else {
+            }
+            else {
                 ERROR "Out of retries.";
                 return $resp;
             }
@@ -624,29 +600,30 @@ sub http_loop {
 ###########################################
 sub http_json {
 ###########################################
-    my( $self, $url, $post_data ) = @_;
+    my ( $self, $url, $post_data ) = @_;
 
     my $req;
 
-    if( $post_data ) {
+    if ($post_data) {
         $req = &HTTP::Request::Common::POST(
             $url->as_string,
-            $self->{ oauth }->authorization_headers(),
-            "Content-Type"=> "application/json",
-            Content       => to_json( $post_data ),
+            $self->{oauth}->authorization_headers(),
+            "Content-Type" => "application/json",
+            Content        => to_json($post_data),
         );
-    } else {
-      $req = HTTP::Request->new(
-        GET => $url->as_string,
-      );
-      $req->header( $self->{ oauth }->authorization_headers() );
+    }
+    else {
+        $req = HTTP::Request->new(
+            GET => $url->as_string,
+        );
+        $req->header( $self->{oauth}->authorization_headers() );
     }
 
-    my $resp = $self->http_loop( $req );
+    my $resp = $self->http_loop($req);
 
-    if( $resp->is_error() ) {
+    if ( $resp->is_error() ) {
         $self->error( $resp->message() );
-        return undef;
+        return;
     }
 
     my $data = from_json( $resp->content() );
@@ -657,36 +634,36 @@ sub http_json {
 ###########################################
 sub file_mime_type {
 ###########################################
-    my( $self, $file ) = @_;
+    my ( $self, $file ) = @_;
 
-      # There don't seem to be great implementations of mimetype
-      # detection on CPAN, so just use this one for now.
+    # There don't seem to be great implementations of mimetype
+    # detection on CPAN, so just use this one for now.
 
-    if( !$self->{ magic } ) {
-        $self->{ magic } =  File::MMagic->new();
+    if ( !$self->{magic} ) {
+        $self->{magic} = File::MMagic->new();
     }
 
-    return $self->{ magic }->checktype_filename( $file );
+    return $self->{magic}->checktype_filename($file);
 }
 
 ###########################################
 sub item_iterator {
 ###########################################
-    my( $self, $data ) = @_;
+    my ( $self, $data ) = @_;
 
     my $idx = 0;
 
-    if( !defined $data ) {
+    if ( !defined $data ) {
         die "no data in item_iterator";
     }
 
     return sub {
         {
-            my $next_item = $data->{ items }->[ $idx++ ];
+            my $next_item = $data->{items}->[ $idx++ ];
 
             return if !defined $next_item;
 
-            if( $next_item->{ labels }->{ trashed } ) {
+            if ( $next_item->{labels}->{trashed} ) {
                 DEBUG "Skipping $next_item->{ title } (trashed)";
                 redo;
             }
@@ -699,23 +676,23 @@ sub item_iterator {
 ###########################################
 sub file_metadata {
 ###########################################
-    my( $self, $file_id ) = @_;
+    my ( $self, $file_id ) = @_;
 
-    LOGDIE 'Deletion requires file_id' if( ! defined $file_id );
+    LOGDIE 'Deletion requires file_id' if ( !defined $file_id );
 
-    my $url = URI->new( $self->{ api_file_url } . "/$file_id" );
+    my $url = URI->new( $self->{api_file_url} . "/$file_id" );
 
     my $req = &HTTP::Request::Common::GET(
         $url->as_string,
-        $self->{ oauth }->authorization_headers(),
+        $self->{oauth}->authorization_headers(),
     );
 
-	my $ua = LWP::UserAgent->new();
-	my $resp = $ua->request( $req );
+    my $ua   = LWP::UserAgent->new();
+    my $resp = $ua->request($req);
 
-	if( $resp->is_error ) {
+    if ( $resp->is_error ) {
         $self->error( $resp->message() );
-        return undef;
+        return;
     }
 
     my $data = from_json( $resp->content() );
@@ -734,24 +711,25 @@ Net::Google::Drive::Simple - Simple modification of Google Drive data
 
 =head1 SYNOPSIS
 
+    use feature 'say';
     use Net::Google::Drive::Simple;
 
-      # requires a ~/.google-drive.yml file with an access token,
-      # see description below.
+    # requires a ~/.google-drive.yml file with an access token,
+    # see description below.
     my $gd = Net::Google::Drive::Simple->new();
 
-    my $children = $gd->children( "/folder/path" );
+    my $children = $gd->children( "/" ); # or any other folder /path/location
 
-    for my $child ( @$children ) {
+    foreach my $item ( @$children ) {
 
-        next if $child->kind() ne 'drive#file';
+        # item is a Net::Google::Drive::Simple::Item object
 
-        next if !$child->can( "downloadUrl" );
-
-        print $child->originalFilename(),
-              " can be downloaded at ",
-              $child->downloadUrl(),
-              "\n";
+        if ( $item->is_folder ) {
+             say "** ", $child->title, " is a folder";
+        } else {
+             say $item->title, " is a file " . $child->mimeType;
+             say $item->originalFilename(), " can be downloaded at ", $child->downloadUrl();
+        }
     }
 
 =head1 DESCRIPTION
@@ -950,8 +928,8 @@ Delete the file with the specified ID from Google Drive.
 
 =item C<$gd-E<gt>drive_mvdir( "/gdrive/path/to/file", "/path/to/new/folder" )>
 
-Move an existing file to a new folder. Removes the file's "parent" 
-setting (pointing to the old folder) and then adds the new folder as a 
+Move an existing file to a new folder. Removes the file's "parent"
+setting (pointing to the old folder) and then adds the new folder as a
 new parent.
 
 =item C<my $metadata_hash_ref = $gd-E<gt>file_metadata( file_id )>
@@ -984,4 +962,5 @@ modify it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
+2019, Nicolas R. <cpan@atoomic.org>
 2012-2019, Mike Schilli <cpan@perlmeister.com>
